@@ -211,6 +211,7 @@ assay_facets: Facets = {
                 "/olink/batch_/combined_npx.xlsx",
                 "/olink/batch_/chip_/assay_npx.xlsx",
                 "/olink/batch_/chip_/assay_raw_ct.csv",
+                "npx|analysis_ready|csv",
             ],
             "Analysis files from the Olink platform.",
         )
@@ -219,7 +220,7 @@ assay_facets: Facets = {
         "Images": FacetConfig(["/ihc/ihc_image."]),
         "Combined Markers": FacetConfig(["csv|ihc marker combined"]),
     },
-    "H&E": {"Images": FacetConfig(["hande/image_file.svs"], "Stained image files.")},
+    "H&E": {"Images": FacetConfig(["/hande/image_file.svs"], "Stained image file.")},
     "TCR": {
         "Source": FacetConfig(
             [
